<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\x72\x64\x50\x72\145\163\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\157\x64\x65\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\x53\x74\141\164\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\x50\171\x74\x68\157\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\122\145\x76\145\162\x73\x65\120\x72\x6f\170\x79"; private const VARNISH_CACHE_SERVER = "\61\62\67\56\x30\x2e\x30\56\61\x3a\66\x30\70\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\x53\137\x4d\105\124\110\117\104" => ["\166\x61\x6c\165\x65" => "\144\x69\x72\145\143\x74", "\x72\141\x77" => false], "\x57\x50\x5f\104\x45\x42\x55\107\x5f\104\111\123\120\x4c\x41\x59" => ["\166\141\x6c\x75\145" => "\x66\x61\154\163\145", "\x72\141\167" => true], "\x57\x50\x5f\x44\x45\102\x55\107\137\114\x4f\x47" => ["\x76\x61\154\165\145" => "\x74\162\165\145", "\x72\x61\x77" => true], "\x43\117\x4e\103\101\x54\x45\x4e\101\124\x45\x5f\x53\x43\x52\x49\120\x54\x53" => ["\x76\x61\154\165\145" => "\146\x61\x6c\163\x65", "\162\x61\x77" => true], "\x41\x55\x54\117\123\x41\x56\x45\x5f\x49\116\124\x45\x52\x56\x41\x4c" => ["\x76\141\154\165\x65" => 600, "\162\141\x77" => true], "\127\120\137\120\x4f\x53\x54\137\x52\105\x56\111\x53\x49\x4f\116\123" => ["\166\x61\154\165\x65" => 5, "\x72\141\x77" => true], "\105\x4d\x50\124\x59\137\124\x52\101\123\110\137\x44\101\x59\123" => ["\166\141\154\x75\x65" => 21, "\x72\x61\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\x50\137\101\114\114\117\x57\137\x4d\125\114\124\x49\123\111\124\105" => ["\x76\x61\x6c\x75\145" => "\x74\x72\x75\145", "\x72\141\167" => true], "\x4d\x55\114\x54\x49\123\x49\124\x45" => ["\x76\x61\154\x75\x65" => "\164\162\165\145", "\x72\x61\167" => true], "\123\125\x42\104\x4f\x4d\101\111\x4e\137\x49\x4e\x53\124\101\114\x4c" => ["\166\x61\x6c\x75\x65" => "\x66\141\x6c\163\x65", "\x72\x61\167" => true], "\104\117\x4d\101\x49\116\x5f\x43\125\122\x52\x45\x4e\124\x5f\123\x49\x54\x45" => ["\x76\141\x6c\x75\x65" => '', "\162\x61\167" => false], "\x50\101\124\110\137\103\125\x52\x52\x45\116\124\x5f\123\x49\x54\x45" => ["\166\141\x6c\x75\x65" => "\x2f", "\x72\141\x77" => false], "\x53\x49\x54\x45\x5f\111\x44\x5f\103\x55\122\122\105\116\124\x5f\123\x49\x54\105" => ["\x76\141\154\165\x65" => 1, "\162\x61\x77" => true], "\102\x4c\x4f\x47\x5f\111\104\x5f\x43\125\x52\x52\105\x4e\x54\x5f\x53\111\x54\x45" => ["\x76\x61\x6c\x75\145" => 1, "\x72\141\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto c4ac2; C8176: $this->domainNameParser = $domainNameParser; goto D001b; fe36f: $this->certificateEntityManager = $certificateEntityManager; goto Deced; c4ac2: $this->configManager = $configManager; goto C94f5; Deced: $this->databaseEntityManager = $databaseEntityManager; goto A7d0e; f4d56: parent::__construct($translator, $logger); goto Ffa03; a89e4: $this->databaseServerEntityManager = $databaseServerEntityManager; goto aeb61; D001b: $this->validator = $validator; goto f4d56; aeb61: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto C8176; C94f5: $this->siteEntityManager = $siteEntityManager; goto fe36f; A7d0e: $this->databaseUserEntityManager = $databaseUserEntityManager; goto a89e4; Ffa03: } public function index(Request $request) : Response { goto d76dc; c902c: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\151\x74\145\x73")); goto df302; df302: goto Ad001; goto e8da1; B25c1: if (true === $hasPermissions) { goto f903a; } goto c902c; d76dc: $hasPermissions = $this->hasPermissions(); goto B25c1; C98bb: return $response; goto Bd284; Cfef7: Ad001: goto C98bb; B0409: $response = $this->render("\x46\162\x6f\156\x74\x65\156\144\x2f\x53\x69\164\x65\x2f\x4e\145\167\x2f\x69\156\144\x65\x78\56\x68\164\155\x6c\56\164\167\151\147", ["\165\163\x65\x72" => $user]); goto Cfef7; e8da1: f903a: goto C93c1; C93c1: $user = $this->getUser(); goto B0409; Bd284: } public function newPythonSite(Request $request) : Response { goto Fb619; B0b71: $response = $this->handleCreatePythonSiteForm($request, $form); goto C2e00; C1764: return $response; goto Ffd15; E7339: a86a8: goto fab7c; C1b3a: E8967: goto fe055; f425c: if (true === $hasPermissions) { goto a86a8; } goto B3e97; Fc74d: fb9f9: goto A9462; Efa00: b917a: goto C1764; A9462: de792: goto C1b3a; Bb8be: $pythonSettings = new PythonSettingsEntity(); goto A9c3a; A9c3a: $form = $this->createPythonSiteForm($pythonSettings); goto af28d; af28d: if (!(true === $request->isMethod("\x50\x4f\123\124"))) { goto E8967; } goto b361b; fab7c: $user = $this->getUser(); goto Bb8be; Fb619: $hasPermissions = $this->hasPermissions(); goto f425c; a3716: goto b917a; goto E7339; B3e97: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\151\x74\145\x73")); goto a3716; C2e00: if (!(false === is_null($response))) { goto fb9f9; } goto D593b; b361b: $form->handleRequest($request); goto a6095; a6095: if (!(true === $form->isSubmitted())) { goto de792; } goto B0b71; D593b: return $response; goto Fc74d; fe055: $response = $this->render("\106\162\157\x6e\164\145\x6e\144\x2f\x53\151\164\x65\x2f\116\145\x77\x2f\x70\171\164\150\157\156\x2e\150\164\155\x6c\56\164\x77\151\147", ["\165\163\x65\x72" => $user, "\146\x6f\x72\x6d" => $form->createView(), "\x66\x6f\x72\155\105\x72\162\x6f\162\163" => $this->formErrors]); goto Efa00; Ffd15: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto D5b1f; C6c2b: $form->add("\x73\x75\142\155\151\164", SubmitType::class, ["\x61\x74\x74\162" => ["\x63\x6c\141\163\x73" => "\x62\164\156\x20\142\x74\x6e\55\154\x67\x20\x62\164\156\55\x62\x6c\x75\x65"], "\154\x61\142\x65\154" => "\103\162\x65\x61\164\x65"]); goto A9aa3; A9aa3: return $form; goto a21b1; D5b1f: $form = $this->createForm("\101\160\x70\x5c\x46\157\162\x6d\x5c\x53\x69\164\x65\116\145\x77\x50\171\x74\x68\x6f\x6e\124\171\x70\145", $pythonSettings, ["\141\143\164\151\x6f\x6e" => $this->generateUrl("\x63\154\160\137\163\x69\164\145\137\x70\x79\164\x68\157\156\137\x6e\x65\x77"), "\155\x65\164\x68\157\x64" => "\x50\x4f\123\124", "\141\x74\x74\x72" => ["\151\x64" => "\x6e\145\x77\55\x70\x79\x74\150\x6f\156\55\x73\151\x74\145\55\x66\157\162\x6d"]]); goto C6c2b; a21b1: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto C6519; ee51d: c4fe4: goto D75fb; Cb012: c10ee: goto C9db4; D5317: $this->formErrors = $this->getErrorMessages($form); goto d6ba2; C9db4: try { goto E93af; b3819: return $response; goto B76d1; c39be: $port = $form->get("\x70\x6f\162\164")->getData(); goto Cf2e2; d3631: $session->getFlashBag()->set("\x73\x75\x63\x63\145\163\163", $this->translator->trans("\x53\151\164\145\x20\150\141\x73\40\x62\x65\145\x6e\40\x63\x72\145\x61\164\x65\144\x2e")); goto e91a0; d2435: $siteUserPassword = $form->get("\x73\151\x74\x65\125\x73\x65\162\x50\x61\163\x73\x77\157\162\x64")->getData(); goto Eddf1; E93af: $session = $request->getSession(); goto f7103; F250d: if (false === is_null($vhostTemplateEntity)) { goto Ddb9a; } goto D2bd7; e91a0: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\151\164\x65\x73")); goto b3819; D19dc: $eventData = ["\x73\x69\x74\x65" => $domainName, "\163\151\x74\x65\x55\x73\145\x72" => $siteUser, "\160\x79\164\150\x6f\156\126\145\162\163\x69\x6f\156" => $pythonVersion, "\x70\157\162\164" => $port]; goto C4af3; C5e76: goto E96ce; goto E2104; B76d1: E96ce: goto Be552; B6acb: $user = $this->getUser(); goto B4db5; B4db5: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto D19dc; Cf2e2: $siteUser = $form->get("\x73\x69\x74\x65\125\163\x65\162")->getData(); goto d2435; a941c: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto F250d; D2bd7: throw new \Exception(sprintf("\126\150\157\x73\x74\x20\x74\x65\x6d\160\154\x61\x74\145\40\42\x25\163\42\40\x6e\157\x74\40\146\157\165\x6e\144\x2e", $vhostTemplateName)); goto C5e76; f7103: $domainName = $form->get("\144\x6f\155\141\151\156\116\x61\x6d\x65")->getData(); goto dd34f; E2104: Ddb9a: goto B6acb; C4af3: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto d3631; dd34f: $pythonVersion = $form->get("\x70\171\x74\x68\157\x6e\x56\x65\x72\163\151\x6f\156")->getData(); goto c39be; Eddf1: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto a941c; Be552: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\145\x72", $this->translator->trans("\101\x6e\40\x65\x72\x72\157\162\x20\150\141\x73\40\157\x63\143\165\x72\x72\145\144\54\x20\x65\x72\162\157\x72\x20\x6d\x65\163\163\x61\x67\x65\x3a\40\x25\145\162\x72\x6f\x72\x4d\x65\163\x73\x61\147\x65\45", ["\x25\145\162\x72\157\162\115\145\163\x73\141\x67\145\x25" => $e->getMessage()])); } goto ee51d; d6ba2: goto c4fe4; goto Cb012; C6519: if (true === $form->isValid()) { goto c10ee; } goto D5317; D75fb: } public function newReverseProxy(Request $request) : Response { goto D3d57; B123e: if (true === $hasPermissions) { goto c6b10; } goto Caa57; Ba3e6: if (!(false === is_null($response))) { goto Fc556; } goto b98cc; Da719: $response = $this->render("\x46\x72\157\x6e\x74\x65\x6e\144\x2f\x53\151\x74\x65\x2f\116\x65\x77\57\x72\x65\166\145\x72\163\x65\55\x70\x72\157\170\x79\56\x68\164\155\x6c\x2e\164\x77\151\x67", ["\x75\x73\145\162" => $user, "\x66\x6f\x72\155" => $form->createView(), "\146\157\162\x6d\x45\x72\x72\x6f\x72\163" => $this->formErrors]); goto Bdcbf; b98cc: return $response; goto ea3d1; Ca95d: b2bac: goto e4709; acdb1: $form = $this->createReverseProxyForm(); goto Fd70a; ea3d1: Fc556: goto Ca95d; Bec2f: $response = $this->handleReverseProxyForm($request, $form); goto Ba3e6; f1c7d: return $response; goto a15eb; Caa57: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\163\151\x74\x65\163")); goto B0bcc; B0bcc: goto f203b; goto B4b56; Bdcbf: f203b: goto f1c7d; Fd70a: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto Ba196; } goto bca0a; B4b56: c6b10: goto F6be9; e4709: Ba196: goto Da719; bca0a: $form->handleRequest($request); goto Abfa4; F6be9: $user = $this->getUser(); goto acdb1; Abfa4: if (!(true === $form->isSubmitted())) { goto b2bac; } goto Bec2f; D3d57: $hasPermissions = $this->hasPermissions(); goto B123e; a15eb: } private function createReverseProxyForm() : Form { goto de5e4; de5e4: $form = $this->createForm("\x41\x70\160\x5c\x46\x6f\162\155\134\123\151\164\145\x4e\145\x77\x52\145\166\x65\162\x73\145\120\x72\x6f\x78\171\124\x79\x70\145", [], ["\141\x63\x74\151\157\x6e" => $this->generateUrl("\x63\x6c\160\x5f\163\151\164\145\x5f\162\x65\x76\x65\162\163\145\137\x70\162\157\170\x79\137\156\x65\x77"), "\x6d\x65\164\150\157\144" => "\120\x4f\123\124", "\141\x74\164\162" => ["\x69\x64" => "\x6e\145\167\x2d\162\x65\x76\145\162\x73\x65\x2d\160\162\157\x78\171\55\x66\x6f\162\155"]]); goto f9dd0; f9dd0: $form->add("\163\x75\x62\155\x69\164", SubmitType::class, ["\141\x74\164\162" => ["\143\154\141\x73\x73" => "\142\x74\x6e\x20\142\x74\156\x2d\x6c\147\x20\x62\x74\156\x2d\x62\154\165\x65"], "\154\141\x62\x65\x6c" => "\x43\x72\x65\141\x74\x65"]); goto f9417; f9417: return $form; goto fc091; fc091: } private function handleReverseProxyForm(Request $request, Form $form) { goto e9a7c; C67de: $this->formErrors = $this->getErrorMessages($form); goto A9c67; c0c49: try { goto f84f8; Ef14e: if (false === is_null($vhostTemplateEntity)) { goto dccd4; } goto Df18b; De184: $reverseProxyUrl = $form->get("\162\x65\x76\145\162\x73\145\x50\162\x6f\170\171\x55\162\x6c")->getData(); goto F87b3; C10c2: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto f3c13; f3c13: $session->getFlashBag()->set("\x73\x75\143\x63\145\x73\163", $this->translator->trans("\122\145\166\145\162\x73\x65\x20\120\x72\x6f\x78\171\40\150\x61\x73\x20\x62\x65\145\x6e\x20\x63\x72\x65\141\x74\x65\x64\56")); goto eaea5; fc740: return $response; goto Df7a5; B6fd4: goto fbe7e; goto A98ba; E7730: $eventData = ["\x73\151\x74\145" => $domainName, "\163\x69\164\145\x55\163\x65\x72" => $siteUser, "\162\x65\x76\145\162\163\x65\x50\x72\x6f\170\171\125\x72\154" => $reverseProxyUrl]; goto C10c2; C69ef: $siteUser = $form->get("\163\x69\164\x65\125\163\145\162")->getData(); goto E09bf; A98ba: dccd4: goto Cd769; E09bf: $siteUserPassword = $form->get("\163\151\164\x65\125\x73\145\162\x50\x61\163\x73\167\x6f\162\144")->getData(); goto De184; Cec0d: $domainName = $form->get("\144\x6f\155\141\x69\x6e\116\141\x6d\145")->getData(); goto C69ef; f84f8: $session = $request->getSession(); goto Cec0d; F87b3: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto Cab8c; eaea5: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\151\x74\145\x73")); goto fc740; Df7a5: fbe7e: goto afe19; b629c: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto E7730; Cab8c: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ef14e; Cd769: $user = $this->getUser(); goto b629c; Df18b: throw new \Exception(sprintf("\126\x68\x6f\163\164\x20\x74\145\x6d\160\x6c\141\x74\145\x20\42\45\x73\42\40\x6e\157\164\x20\x66\x6f\x75\156\144\56", $vhostTemplateName)); goto B6fd4; afe19: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\x65\162", $this->translator->trans("\101\x6e\40\x65\162\x72\157\162\40\x68\x61\x73\x20\x6f\143\x63\x75\x72\162\145\144\54\x20\145\x72\162\x6f\162\x20\x6d\x65\163\x73\x61\147\x65\x3a\40\x25\x65\x72\162\x6f\162\115\145\x73\x73\141\x67\x65\x25", ["\x25\x65\x72\162\157\x72\115\145\163\x73\141\x67\145\x25" => $e->getMessage()])); } goto c1c62; c1c62: a2df8: goto c48c5; F45f7: cfc3c: goto c0c49; e9a7c: if (true === $form->isValid()) { goto cfc3c; } goto C67de; A9c67: goto a2df8; goto F45f7; c48c5: } public function newNodejsSite(Request $request) : Response { goto b886b; b2118: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\x69\x74\145\163")); goto F79f0; f675b: $response = $this->handleCreateNodejsSiteForm($request, $form); goto fdf2e; b4bc0: return $response; goto Eb213; b43e6: $response = $this->render("\106\162\x6f\156\164\x65\x6e\x64\57\123\151\164\145\57\116\x65\x77\57\x6e\x6f\144\x65\152\163\56\150\164\x6d\x6c\56\164\167\x69\x67", ["\165\163\x65\x72" => $user, "\146\157\162\155" => $form->createView(), "\x66\157\162\x6d\105\x72\x72\157\x72\x73" => $this->formErrors]); goto B2cbf; C36b1: Ac4da: goto e8b7d; Aa59a: $form = $this->createNodejsSiteForm($nodejsSettings); goto e3e80; cf3f2: $form->handleRequest($request); goto cedbc; e3e80: if (!(true === $request->isMethod("\120\x4f\x53\x54"))) { goto aab95; } goto cf3f2; fdf2e: if (!(false === is_null($response))) { goto d9596; } goto a3627; cedbc: if (!(true === $form->isSubmitted())) { goto F6639; } goto f675b; b886b: $hasPermissions = $this->hasPermissions(); goto e3b73; e3b73: if (true === $hasPermissions) { goto Ac4da; } goto b2118; Ad3db: $nodejsSettings = new NodejsSettingsEntity(); goto Aa59a; e8b7d: $user = $this->getUser(); goto Ad3db; B2cbf: A1427: goto b4bc0; a3627: return $response; goto Ed817; Ed817: d9596: goto bed35; ccfd0: aab95: goto b43e6; bed35: F6639: goto ccfd0; F79f0: goto A1427; goto C36b1; Eb213: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto fc06a; Ab882: $form->add("\x73\165\x62\155\151\164", SubmitType::class, ["\141\x74\x74\162" => ["\143\x6c\x61\163\163" => "\x62\164\x6e\x20\x62\164\x6e\x2d\x6c\x67\40\x62\x74\156\55\x62\154\165\145"], "\x6c\x61\x62\x65\x6c" => "\103\x72\x65\141\x74\145"]); goto a3d67; a3d67: return $form; goto Fec24; fc06a: $form = $this->createForm("\101\160\x70\134\x46\157\162\155\134\123\151\164\145\x4e\145\167\x4e\x6f\x64\145\x6a\163\x54\x79\160\x65", $nodejsSettings, ["\x61\143\x74\x69\157\156" => $this->generateUrl("\x63\154\160\x5f\163\151\x74\x65\137\x6e\x6f\144\145\152\163\137\x6e\x65\x77"), "\155\145\x74\150\x6f\144" => "\x50\117\x53\124", "\141\x74\164\x72" => ["\x69\x64" => "\x6e\x65\x77\55\156\157\144\145\x6a\x73\55\x73\151\x74\145\x2d\146\x6f\162\x6d"]]); goto Ab882; Fec24: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto F0714; e98f9: goto D47fb; goto Cbae0; af7ae: D47fb: goto C5cb7; Cbae0: ecf2e: goto e09d0; e09d0: try { goto ec362; Cb356: return $response; goto Cc8f3; e91ad: $user = $this->getUser(); goto cefa1; Cc8f3: Ed8d3: goto Dddcf; cefa1: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto C5cd0; c733b: $siteUserPassword = $form->get("\x73\151\x74\x65\x55\163\x65\x72\120\141\163\x73\167\x6f\162\x64")->getData(); goto ffd88; B6f66: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\164\145\163")); goto Cb356; f4994: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto d11fb; b0428: $siteUser = $form->get("\x73\151\164\x65\125\x73\x65\162")->getData(); goto c733b; d11fb: $session->getFlashBag()->set("\163\x75\x63\143\x65\x73\163", $this->translator->trans("\x53\151\x74\x65\40\x68\141\x73\40\x62\x65\145\156\40\143\x72\145\x61\164\x65\144\56")); goto B6f66; eeefe: a7268: goto e91ad; C5cd0: $eventData = ["\x73\x69\164\x65" => $domainName, "\163\151\164\145\x55\x73\x65\x72" => $siteUser, "\156\157\x64\145\x6a\x73\x56\x65\x72\163\151\x6f\156" => $nodejsVersion, "\160\x6f\x72\164" => $port]; goto f4994; ffd88: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto F364c; be31c: goto Ed8d3; goto eeefe; F364c: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto C26d0; F4cca: $domainName = $form->get("\x64\157\155\x61\x69\156\116\x61\155\x65")->getData(); goto Da299; ec038: throw new \Exception(sprintf("\x56\150\157\x73\164\40\x74\145\x6d\x70\x6c\x61\164\x65\40\x22\45\x73\x22\x20\x6e\157\x74\40\146\157\x75\156\144\56", $vhostTemplateName)); goto be31c; ec362: $session = $request->getSession(); goto F4cca; Da299: $nodejsVersion = $form->get("\156\157\x64\x65\x6a\163\x56\x65\x72\x73\x69\x6f\156")->getData(); goto e1084; e1084: $port = $form->get("\160\x6f\x72\x74")->getData(); goto b0428; C26d0: if (false === is_null($vhostTemplateEntity)) { goto a7268; } goto ec038; Dddcf: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\x67\x65\x72", $this->translator->trans("\x41\x6e\40\145\x72\162\x6f\x72\40\150\141\163\40\x6f\x63\x63\165\162\162\145\144\x2c\x20\145\162\x72\157\162\40\x6d\x65\163\x73\141\x67\x65\72\x20\45\x65\x72\x72\x6f\x72\x4d\x65\163\x73\x61\x67\145\x25", ["\45\145\x72\x72\157\162\115\145\163\x73\141\x67\x65\45" => $e->getMessage()])); } goto af7ae; F0714: if (true === $form->isValid()) { goto ecf2e; } goto B1962; B1962: $this->formErrors = $this->getErrorMessages($form); goto e98f9; C5cb7: } public function newStaticSite(Request $request) : Response { goto c66ef; F5569: $response = $this->handleCreateStaticSiteForm($request, $form); goto E9331; Da689: D6a10: goto e9a88; F7cdb: eef90: goto E6c2c; Eaa7f: return $response; goto D6625; B0c86: e52a3: goto E1401; Edaf7: f366b: goto F7cdb; D6625: Da64a: goto Edaf7; E1401: return $response; goto dac05; e9a88: $user = $this->getUser(); goto D732c; ea546: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\x69\x74\145\163")); goto f8ac5; f8ac5: goto e52a3; goto Da689; Bfc3f: if (!(true === $form->isSubmitted())) { goto f366b; } goto F5569; f7633: if (!(true === $request->isMethod("\x50\117\123\124"))) { goto eef90; } goto c8835; D732c: $form = $this->createStaticSiteForm(); goto f7633; E6c2c: $response = $this->render("\x46\162\157\x6e\164\145\x6e\x64\x2f\x53\x69\164\145\57\116\x65\167\x2f\x73\164\141\164\x69\143\x2e\150\x74\x6d\154\x2e\164\x77\151\147", ["\165\x73\x65\162" => $user, "\x66\157\x72\x6d" => $form->createView(), "\146\157\162\155\105\162\162\x6f\162\163" => $this->formErrors]); goto B0c86; c66ef: $hasPermissions = $this->hasPermissions(); goto Dd2fe; E9331: if (!(false === is_null($response))) { goto Da64a; } goto Eaa7f; c8835: $form->handleRequest($request); goto Bfc3f; Dd2fe: if (true === $hasPermissions) { goto D6a10; } goto ea546; dac05: } private function createStaticSiteForm() : Form { goto Ffea3; c0309: $form->add("\x73\165\x62\x6d\x69\164", SubmitType::class, ["\x61\x74\164\162" => ["\143\x6c\141\x73\163" => "\x62\164\x6e\x20\142\x74\x6e\55\x6c\x67\40\x62\164\156\55\x62\154\165\145"], "\154\x61\x62\x65\154" => "\103\x72\145\x61\164\145"]); goto a8460; a8460: return $form; goto c66d1; Ffea3: $form = $this->createForm("\101\160\160\x5c\106\157\162\x6d\x5c\123\x69\164\x65\116\145\x77\x53\x74\x61\164\151\x63\124\171\160\145", [], ["\141\143\x74\x69\157\156" => $this->generateUrl("\143\154\x70\x5f\x73\x69\x74\x65\137\163\164\141\164\x69\143\137\156\x65\167"), "\x6d\x65\164\150\157\144" => "\120\x4f\123\x54", "\141\164\164\162" => []]); goto c0309; c66d1: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto E8f50; Ae3fa: df45e: goto Ac8cb; Dfc44: goto B0574; goto Ae3fa; E8f50: if (true === $form->isValid()) { goto df45e; } goto eda4c; eda4c: $this->formErrors = $this->getErrorMessages($form); goto Dfc44; a6d56: B0574: goto a7715; Ac8cb: try { goto Acd52; A949d: if (false === is_null($vhostTemplateEntity)) { goto f4d79; } goto Dcfc8; Ac2b5: $siteUser = $form->get("\x73\x69\x74\x65\125\x73\145\x72")->getData(); goto a4026; E0b73: goto c41f2; goto A86f4; D6738: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto C9ccb; c80d9: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\151\164\145\x73")); goto c6952; f00ea: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto b1ce3; a4026: $siteUserPassword = $form->get("\x73\x69\164\x65\125\x73\x65\162\120\x61\x73\x73\x77\x6f\x72\x64")->getData(); goto f00ea; a752e: $domainName = $form->get("\x64\157\x6d\x61\151\x6e\x4e\141\x6d\145")->getData(); goto Ac2b5; c6952: return $response; goto ef933; d64b3: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto C7539; b1ce3: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto A949d; A86f4: f4d79: goto c39c7; c39c7: $user = $this->getUser(); goto d64b3; Acd52: $session = $request->getSession(); goto a752e; C7539: $eventData = ["\163\151\164\145" => $domainName, "\163\x69\x74\x65\x55\163\145\162" => $siteUser]; goto D6738; Dcfc8: throw new \Exception(sprintf("\x56\150\157\x73\x74\40\x74\145\155\160\x6c\x61\164\x65\40\x22\45\163\42\x20\x6e\x6f\164\40\146\x6f\165\x6e\144\x2e", $vhostTemplateName)); goto E0b73; ef933: c41f2: goto A9d76; C9ccb: $session->getFlashBag()->set("\x73\165\143\x63\x65\163\163", $this->translator->trans("\x53\151\x74\145\x20\x68\x61\163\x20\142\145\x65\156\40\143\x72\x65\141\x74\145\x64\x2e")); goto c80d9; A9d76: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\x67\145\x72", $this->translator->trans("\101\x6e\40\145\162\x72\157\x72\40\x68\141\x73\40\157\143\x63\165\x72\x72\145\144\x2c\x20\x65\x72\x72\157\162\x20\x6d\x65\163\x73\141\x67\x65\72\40\45\145\x72\x72\157\x72\115\145\x73\163\141\147\145\45", ["\45\x65\162\162\x6f\162\115\145\x73\163\x61\147\145\45" => $e->getMessage()])); } goto a6d56; a7715: } public function newPhpSite(Request $request) : Response { goto a57ee; B3388: if (!(true === $form->isSubmitted())) { goto c0e51; } goto aea8f; C1a88: Dabb8: goto F81c0; ea200: return $response; goto a0a14; a57ee: $hasPermissions = $this->hasPermissions(); goto F4e61; aba82: $form->handleRequest($request); goto B3388; F7d24: A0954: goto a0377; c031a: return $response; goto C1a88; ad396: Af367: goto ea200; F81c0: c0e51: goto F7d24; afda9: goto Af367; goto f1eb6; B48e6: $form = $this->createPhpSiteForm(); goto c885d; C55d9: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\x73\151\164\145\163")); goto afda9; c885d: if (!(true === $request->isMethod("\x50\x4f\x53\x54"))) { goto A0954; } goto aba82; f1eb6: Bbc52: goto b3453; aea8f: $response = $this->handleCreatePhpSiteForm($request, $form); goto Aba46; a0377: $response = $this->render("\x46\162\157\156\164\x65\x6e\144\57\x53\151\164\x65\x2f\116\x65\x77\x2f\160\x68\160\56\x68\164\x6d\x6c\x2e\164\x77\x69\x67", ["\165\163\x65\x72" => $user, "\146\157\162\x6d" => $form->createView(), "\146\x6f\x72\x6d\x45\x72\x72\157\162\163" => $this->formErrors]); goto ad396; F4e61: if (true === $hasPermissions) { goto Bbc52; } goto C55d9; b3453: $user = $this->getUser(); goto B48e6; Aba46: if (!(false === is_null($response))) { goto Dabb8; } goto c031a; a0a14: } private function createPhpSiteForm() : Form { goto faacb; Aa7e1: return $form; goto c6c4f; faacb: $form = $this->createForm("\101\160\160\x5c\x46\157\x72\x6d\x5c\123\x69\164\x65\x4e\x65\167\x50\x68\x70\124\171\160\x65", [], ["\141\143\x74\151\x6f\x6e" => $this->generateUrl("\x63\154\160\x5f\163\x69\164\145\x5f\x70\x68\x70\x5f\x6e\x65\x77"), "\155\145\164\150\157\x64" => "\x50\117\x53\124", "\x61\x74\x74\162" => []]); goto c0e44; c0e44: $form->add("\163\165\142\x6d\x69\164", SubmitType::class, ["\141\164\164\162" => ["\x63\x6c\x61\x73\163" => "\x62\x74\x6e\40\x62\164\156\x2d\154\147\x20\142\x74\x6e\55\x62\154\x75\145"], "\x6c\x61\x62\x65\x6c" => "\x43\x72\x65\x61\164\x65"]); goto Aa7e1; c6c4f: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto b7973; b7973: if (true === $form->isValid()) { goto e8b97; } goto D6bd3; F5bdb: goto bc26d; goto Ab367; Ab367: e8b97: goto A07e6; D6bd3: $this->formErrors = $this->getErrorMessages($form); goto F5bdb; A07e6: try { goto b1a60; Aab25: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto F940c; } goto C4f12; ba064: $siteUserPassword = $form->get("\x73\x69\164\145\125\163\145\162\120\141\x73\163\167\157\162\144")->getData(); goto C45c7; C4f12: $rootDirectory = sprintf("\45\x73\57\x25\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\57"), "\57")); goto Afd62; d5d90: throw new \Exception(sprintf("\x56\150\x6f\x73\x74\x20\164\x65\x6d\160\154\x61\x74\145\x20\x22\45\x73\x22\x20\x6e\x6f\164\40\146\x6f\x75\x6e\144\x2e", $vhostTemplateName)); goto Af852; Af852: goto ead9f; goto Ce383; A1eff: if (false === is_null($vhostTemplateEntity)) { goto c360a; } goto d5d90; fcdce: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto b5111; bb1cd: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto b5cd1; f99b1: $varnishCacheSettings = []; goto Ce189; eef67: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto Aeb7b; bdffc: return $response; goto ded6a; b1a60: $session = $request->getSession(); goto E014c; b5cd1: $eventData = ["\x73\x69\164\x65" => $domainName, "\166\x68\x6f\163\x74\124\x65\x6d\x70\x6c\141\x74\145\x4e\141\x6d\145" => $vhostTemplateName, "\160\150\x70\126\x65\162\163\x69\157\x6e" => $phpVersion, "\x73\151\x74\145\x55\163\x65\x72" => $siteUser]; goto eef67; Ce383: c360a: goto D798e; C45c7: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto A1eff; Aeb7b: $session->getFlashBag()->set("\x73\x75\x63\143\x65\163\163", $this->translator->trans("\123\x69\164\145\40\150\x61\x73\40\142\x65\x65\156\x20\x63\162\145\x61\164\x65\144\56")); goto Ae2c6; d8ae1: $phpVersion = $form->get("\x70\x68\160\x56\x65\162\163\151\x6f\156")->getData(); goto Cef30; ded6a: ead9f: goto C29a1; Afd62: F940c: goto f99b1; d55e4: $domainName = $form->get("\144\157\155\141\151\156\116\x61\155\145")->getData(); goto d8ae1; Ce189: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto a528a; } goto fcdce; b5111: a528a: goto bb1cd; b19b6: $rootDirectory = $domainName; goto Aab25; Ae2c6: $response = $this->redirect($this->generateUrl("\143\154\160\137\x73\x69\164\145\163")); goto bdffc; D798e: $user = $this->getUser(); goto b19b6; E014c: $vhostTemplateName = $form->get("\x61\x70\x70\154\151\x63\x61\x74\151\157\x6e")->getData(); goto d55e4; Cef30: $siteUser = $form->get("\x73\151\x74\145\125\163\x65\162")->getData(); goto ba064; C29a1: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\x65\162", $this->translator->trans("\101\156\40\145\x72\x72\157\162\x20\x68\141\x73\x20\x6f\x63\x63\165\162\x72\145\x64\x2c\x20\x65\x72\x72\x6f\162\40\x6d\x65\163\x73\141\x67\x65\72\40\45\x65\162\162\157\162\x4d\x65\163\163\141\147\x65\45", ["\x25\145\x72\162\x6f\x72\115\145\x73\163\141\x67\x65\45" => $e->getMessage()])); } goto Ef0f9; Ef0f9: bc26d: goto D3cf8; D3cf8: } public function newWordPressSite(Request $request) : Response { goto a5d40; D2803: D14ae: goto Bd74d; Bd74d: $user = $this->getUser(); goto D350b; f82e9: return $response; goto ff79a; ee58c: $response = $this->handleCreateWordPressSiteForm($request, $form); goto bdb11; b0f10: $form->handleRequest($request); goto dd580; bdb11: if (!(false === is_null($response))) { goto c7bab; } goto f82e9; ff79a: c7bab: goto Bc9f6; dd580: if (!(true === $form->isSubmitted())) { goto Bda7d; } goto ee58c; D350b: $form = $this->createWordPressSiteForm(); goto de8e6; ba13e: if (true === $hasPermissions) { goto D14ae; } goto d6dcd; b6ee0: goto Be445; goto D2803; Ca1db: Be445: goto Fa377; de8e6: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto b6e26; } goto b0f10; ba1e1: $response = $this->render("\x46\162\157\x6e\164\145\156\x64\57\123\x69\164\145\57\x4e\145\167\57\167\x6f\x72\x64\160\x72\145\x73\163\56\150\x74\155\x6c\x2e\164\167\x69\147", ["\165\163\145\162" => $user, "\x66\x6f\162\155" => $form->createView(), "\146\x6f\162\155\105\162\x72\157\162\x73" => $this->formErrors]); goto Ca1db; d6dcd: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\151\x74\145\x73")); goto b6ee0; a5d40: $hasPermissions = $this->hasPermissions(); goto ba13e; Fa377: return $response; goto E5e66; Bc9f6: Bda7d: goto Abbea; Abbea: b6e26: goto ba1e1; E5e66: } private function createWordPressSiteForm() : Form { goto ab5e3; ab5e3: $form = $this->createForm("\x41\160\x70\x5c\x46\157\x72\x6d\x5c\123\x69\164\145\x4e\x65\167\x57\157\162\x64\x50\x72\145\163\x73\x54\171\160\145", [], ["\141\143\x74\151\157\x6e" => $this->generateUrl("\x63\x6c\x70\137\163\151\164\145\137\167\x6f\x72\144\160\x72\145\x73\x73\x5f\x6e\145\x77"), "\155\145\x74\150\157\x64" => "\x50\117\123\x54", "\x61\x74\x74\162" => ["\151\144" => "\156\145\167\x2d\x77\x6f\162\144\160\x72\x65\163\163\x2d\163\x69\164\x65\55\146\157\x72\155"]]); goto f936e; c106b: return $form; goto C27cf; f936e: $form->add("\x73\165\142\155\151\164", SubmitType::class, ["\x61\164\x74\162" => ["\x63\x6c\x61\x73\163" => "\x62\x74\x6e\40\142\164\156\x2d\154\147\40\142\x74\x6e\x2d\x62\154\165\145"], "\x6c\141\x62\145\154" => "\x43\x72\145\x61\164\145"]); goto c106b; C27cf: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto F9e3c; bc037: b818b: goto E14fd; f243f: $this->formErrors = $this->getErrorMessages($form); goto A4a61; C8212: D986a: goto E4a36; F9e3c: if (true === $form->isValid()) { goto D986a; } goto f243f; A4a61: goto b818b; goto C8212; E4a36: try { goto Cd06c; A9c58: return $response; goto Cf27f; Bb55a: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto a1222; a1222: $instance = $request->attributes->get("\151\x6e\163\164\x61\156\x63\145"); goto Ed0a5; D023b: $session->set("\163\151\164\x65\103\162\x65\144\145\x6e\x74\151\141\x6c\x73", $siteCredentials); goto F343f; A5631: D33d4: goto f3415; D2e36: $databaseUserEntity->setUserName($databaseUserName); goto A8281; Cd06c: $user = $this->getUser(); goto Ac994; e9b58: $domainName = $form->get("\144\157\155\x61\x69\156\x4e\141\x6d\x65")->getData(); goto ee869; ec1be: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto b9d0e; b9cc8: $this->siteEntityManager->updateEntity($siteEntity); goto Ed23a; c530b: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto B4d13; F5fb0: $databaseManager->createUser($databaseUserEntity); goto b9cc8; D6c93: $databaseEntity = $this->databaseEntityManager->createEntity(); goto C4fb5; b70d3: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto D33d4; } goto bddc0; E3f6f: $databaseEntity->addUser($databaseUserEntity); goto Bf068; cb685: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto d3905; Ac994: $session = $request->getSession(); goto e9b58; ebf03: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto D2e36; a02e0: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto a1a2a; Ed0a5: $siteCredentials = [$this->translator->trans("\x53\151\x74\145") => [$this->translator->trans("\111\x50\x20\x41\x64\x64\x72\145\163\163") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\157\155\x61\x69\x6e\x20\116\x61\155\145") => sprintf("\150\x74\x74\x70\163\72\x2f\x2f\45\x73", $domainName), $this->translator->trans("\123\x69\x74\x65\40\125\x73\145\x72") => $siteUser, $this->translator->trans("\120\141\163\x73\167\x6f\x72\144") => $siteUserPassword]]; goto Fd777; bcfb7: $databaseEntity->setName($databaseName); goto c5923; c5923: $databaseEntity->setSite($siteEntity); goto ebf03; Db000: $adminUserName = $form->get("\141\x64\155\x69\x6e\x55\163\145\x72\116\141\x6d\x65")->getData(); goto d4602; Ed1c1: $databaseName = $this->getUniqueDatabaseName($generatedName); goto E489a; a1a2a: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\151\164\x65\137\167\157\162\144\x70\162\x65\x73\x73\x5f\151\x6e\x73\x74\141\x6c\x6c\145\x64")); goto A9c58; Bf068: $siteEntity->addDatabase($databaseEntity); goto D33f5; Fc2d2: Ddd8f: goto D023b; A91eb: $siteUserPassword = $form->get("\x73\151\x74\145\125\x73\x65\162\x50\141\x73\x73\167\157\x72\144")->getData(); goto c530b; Fd777: if (!(false === is_null($siteEntity))) { goto Ddd8f; } goto Ed1c1; b7aba: $databaseManager->createDatabase($databaseEntity); goto F5fb0; B4d13: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto E38fd; Fc70e: $siteCredentials[$this->translator->trans("\x44\x61\x74\x61\x62\x61\163\x65")] = [$this->translator->trans("\x48\x6f\163\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\157\x72\164") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\104\141\164\141\x62\141\x73\145\40\x4e\141\x6d\x65") => $databaseName, $this->translator->trans("\104\141\164\x61\x62\x61\x73\145\x20\x55\163\x65\162\x20\x4e\141\x6d\x65") => $databaseUserName, $this->translator->trans("\104\141\164\141\142\x61\163\x65\40\125\x73\145\162\x20\x50\x61\163\163\167\x6f\x72\144") => $databaseUserPassword]; goto A77c6; Ed23a: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto Fc70e; d16a1: $isMultiSite = $form->get("\155\165\154\164\151\x53\151\x74\145")->getData(); goto ac9da; d3905: $url = sprintf("\150\x74\x74\x70\163\x3a\x2f\x2f\45\163", $siteEntity->getDomainName()); goto Be5f9; C4fb5: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto bcfb7; F343f: $eventData = ["\x73\151\164\145" => $domainName, "\163\x69\164\x65\125\x73\x65\162" => $siteUser]; goto a02e0; B51aa: $siteUser = $form->get("\163\x69\x74\145\x55\163\145\x72")->getData(); goto A91eb; e8b25: $adminEmail = $form->get("\141\144\x6d\x69\x6e\105\155\141\151\x6c")->getData(); goto d16a1; f3415: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto Bb55a; E38fd: $varnishCacheSettings = []; goto b70d3; A77c6: $siteCredentials["\127\x6f\x72\x64\x50\x72\x65\x73\x73"] = [$this->translator->trans("\x41\144\x6d\x69\x6e\40\105\55\x4d\141\151\x6c") => $adminEmail, $this->translator->trans("\x41\144\155\x69\x6e\x20\125\x73\145\162\40\x4e\141\155\145") => $adminUserName, $this->translator->trans("\x41\144\155\x69\x6e\40\120\x61\x73\x73\x77\x6f\x72\144") => $adminPassword, $this->translator->trans("\x41\144\155\x69\156\x20\x55\162\x6c") => sprintf("\150\x74\x74\x70\x73\x3a\x2f\x2f\x25\163\57\x77\x70\x2d\x61\x64\x6d\x69\x6e\x2f", rtrim($domainName, "\x2f"))]; goto Fc2d2; bddc0: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto A5631; d4602: $adminPassword = $form->get("\x61\144\155\x69\156\x50\141\163\163\167\157\x72\x64")->getData(); goto e8b25; A8281: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto ec1be; ac9da: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto D6c93; ee869: $generatedName = $this->generateNameFromDomainName($domainName); goto B51aa; D33f5: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto b7aba; b9d0e: $databaseUserEntity->setDatabase($databaseEntity); goto E3f6f; Be5f9: $title = $form->get("\x73\x69\x74\x65\x54\x69\x74\154\145")->getData(); goto Db000; E489a: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto cb685; Cf27f: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\147\x65\x72", $this->translator->trans("\101\156\40\145\162\162\x6f\162\x20\150\x61\163\x20\x6f\x63\x63\165\162\162\x65\144\x2c\40\x65\x72\x72\x6f\162\x20\155\145\163\163\x61\x67\145\x3a\x20\x25\x65\x72\162\x6f\162\115\145\x73\x73\141\147\145\45", ["\x25\145\162\162\x6f\x72\115\145\x73\163\x61\x67\145\45" => $e->getMessage()])); } goto bc037; E14fd: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto a87dd; A354e: $wordPressInstaller->downloadAndExtractLatestVersion(); goto af966; affe8: e2ba8: goto A56aa; Ae5b1: if (!(true === $isMultiSite)) { goto Faa0c; } goto E760b; af966: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto Abaae; A56aa: Faa0c: goto f5b61; a87dd: $databaseHost = sprintf("\x25\163\x3a\45\x73", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto ea0ba; F0834: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\x6c\x75\x65"], $config["\x72\x61\167"]); Dbcdc: } goto Bd19f; Bd19f: A553e: goto Ae5b1; ea0ba: $databaseName = $databaseEntity->getName(); goto c2174; e1e96: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\x6c\165\145"], $config["\162\141\167"]); D993a: } goto affe8; c2174: $databaseUserName = $databaseUserEntity->getUserName(); goto A731b; Abaae: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto F0834; D7079: $wordPressInstaller = new WordPressInstaller($siteEntity); goto A354e; f5b61: $wordPressInstaller->resetPermissions(); goto F66ad; A731b: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto D7079; E760b: $this->wordPressMultiSiteConfigValues["\x44\117\115\101\111\116\137\x43\x55\122\122\x45\116\124\x5f\x53\111\124\x45"]["\166\x61\x6c\165\x65"] = $siteEntity->getDomainName(); goto e1e96; F66ad: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto de776; bc910: if (!(true === $varnishCache)) { goto a20d9; } goto fd398; Fc995: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C772a; Dd649: $subjectAlternativeNames[] = sprintf("\167\x77\167\56\45\x73", $domainName); goto D9be0; ac89b: $subjectAlternativeNames[] = $registrableDomain; goto Fb43b; ffc47: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto Fcf79; } goto d1077; Ff22b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\x2e\x2e\x2f\x2e\x2e\57\162\x65\163\x6f\x75\162\x63\x65\163\57\x6e\147\x69\156\170\x2f\166\150\x6f\163\x74\137\164\145\155\x70\x6c\x61\164\x65\57\x72\x65\x64\151\x72\x65\x63\x74"); goto a6151; Bc6f2: $phpSiteCreator = new PhpSiteCreator($phpSite); goto Dca35; d08f7: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D5640; c21cf: A6634: goto D41cc; Fe5d9: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto fb2f1; e4787: $siteConstraints = $this->validator->validate($siteEntity); goto fd5c4; f62ed: if (!(false === empty($varnishCache))) { goto A6634; } goto e1270; fe8f2: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto B4536; fd117: if (true === isset($_ENV["\x41\x50\x50\137\110\124\x54\x50\63"]) && "\x74\162\165\x65" === $_ENV["\x41\120\x50\x5f\x48\124\x54\x50\63"]) { goto c39d5; } goto Ff22b; D876c: $phpSettingsEntity = new PhpSettingsEntity(); goto Dd18f; bb561: $siteEntity->setType(SiteEntity::TYPE_PHP); goto a2876; Ce5c7: $siteEntity->setCertificate($certificateEntity); goto Ce01d; C5119: $certificateEntity->setSite($siteEntity); goto cfef7; ca919: $phpSite->setPhpSettings($phpSettingsEntity); goto bb0e6; F2acc: $phpSiteCreator->createIndexPhp(); goto E7e84; F2e7e: $siteEntity->setUser($siteUser); goto ee9f3; e3976: if (!(true === is_null($subdomain))) { goto a54fb; } goto Dd649; f678d: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto C3308; d38f3: b9183: goto e05d1; cfef7: $rsaKeyGenerator = new RsaKeyGenerator(); goto Fe5d9; f6741: $this->siteEntityManager->updateEntity($siteEntity); goto c6cf7; dd1b5: $phpSite->setUser($siteEntity->getUser()); goto c74b9; f0014: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\57"); goto Ef9c8; C85b9: a20d9: goto b5fe9; D9be0: a54fb: goto Da3cc; Afcaa: $phpSite->setSubdomain($subdomain); goto Cfadf; F3b8e: $phpSiteCreator->createRootDirectory(); goto eb645; D41cc: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto Bcd57; } goto fd117; f23a2: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\57\x2e\x2e\57\56\56\57\x72\145\x73\157\x75\x72\x63\145\163\x2f\156\147\151\x6e\170\x2f\x76\150\157\x73\164\x5f\164\x65\x6d\160\x6c\141\x74\x65\x2f\x72\145\144\x69\x72\x65\143\164\55\150\164\x74\x70\x33"); goto cddb0; a9aca: $phpSite->setDomainName($domainName); goto D3209; D3209: $phpSite->setRegistrableDomain($registrableDomain); goto Afcaa; B4536: $certificateEntity->setDefaultCertificate(true); goto E1df5; F3a8a: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Ab315; B3d3f: $phpSiteCreator->reloadPhpFpmService(); goto bc910; b5fe9: $phpSiteCreator->createNginxVhost(); goto f0c2c; a2876: $siteEntity->setDomainName($domainName); goto F2e7e; Dbd2b: $vhostTemplate = sprintf("\x25\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto d38f3; ee9f3: $siteEntity->setUserPassword($siteUserPassword); goto C81ce; c74b9: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto a9aca; D5640: $siteEntity = $this->siteEntityManager->createEntity(); goto bb561; B5961: $defaultVarnishCacheSettings = ["\x65\x6e\141\142\154\145\x64" => false, "\163\145\162\x76\x65\162" => self::VARNISH_CACHE_SERVER, "\143\x61\143\x68\x65\124\141\147\x50\162\x65\146\151\x78" => substr(md5(time()), 0, 4)]; goto Bf8cf; B98b5: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto d08f7; Ccda8: if (!(false === empty($redirectionVhostTemplate))) { goto b9183; } goto Dbd2b; E7e84: $phpSiteCreator->createPrivateKeyAndCertificate(); goto aad2e; d1077: $constraintViolationList = new ConstraintViolationList(); goto c6f10; d7808: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto a8a43; eb645: $phpSiteCreator->createLogrotateFile(); goto F2acc; F904c: $phpSettingsEntity->setSite($siteEntity); goto e4787; c6f10: $constraintViolationList->addAll($siteConstraints); goto Daf13; D8314: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto a3042; D34b9: $certificateEntity->setCsr($csr); goto f678d; bc99f: c39d5: goto f23a2; e1270: $siteEntity->setVarnishCache(true); goto c21cf; E1df5: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto D34b9; fd398: $phpSite->setVarnishCache(true); goto B5961; af2b3: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Ccda8; C81ce: $siteEntity->setRootDirectory($rootDirectory); goto f62ed; Eace7: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto E3c0a; Dca35: $phpSiteCreator->createUser(); goto F3b8e; Ee747: $phpSiteCreator->resetPermissions(); goto Ca4c7; c6cf7: return $siteEntity; goto C9aa5; F4c06: $phpSite->setCertificate($certificateEntity); goto ca919; Bf8cf: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto e8424; b6d0d: $phpSettingsEntity->setPhpVersion($phpVersion); goto F904c; bbde1: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto C85b9; Daf13: $constraintViolationList->addAll($phpSettingsConstraints); goto F3a8a; Dd18f: $siteEntity->setPhpSettings($phpSettingsEntity); goto b6d0d; E3c0a: $subdomain = $resolvedDomainName->subDomain()->toString(); goto F474a; Dcb4a: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Ad148; C1e39: $siteEntity->setVhostTemplate($vhostTemplate); goto D876c; F474a: $subdomain = false === empty($subdomain) ? $subdomain : null; goto B98b5; a6151: goto ae9c2; goto bc99f; aad2e: $phpSiteCreator->createPhpFpmPool(); goto B3d3f; Ab315: throw new \Exception(implode("\73\40", $errorMessages)); goto b1290; Da3cc: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto B970d; } goto ac89b; cddb0: ae9c2: goto af2b3; c53a0: $certificateEntity = $this->certificateEntityManager->createEntity(); goto C5119; a3042: $csr = $csrGenerator->generate(); goto fe8f2; Ad148: $vhostTemplate->resetProcessors(); goto D3d05; C3308: $certificateEntity->setCertificate($selfSignedCertificate); goto Ce5c7; fd5c4: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto ffc47; Ca4c7: $vhostTemplate = new PhpVhostTemplate($phpSite); goto Dcb4a; de776: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto f0014; bb0e6: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Bc6f2; fb2f1: $subjectAlternativeNames = []; goto e3976; a8a43: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto dd71e; f0c2c: $phpSiteCreator->reloadNginxService(); goto Ee747; C772a: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f6741; b1290: Fcf79: goto c53a0; e05d1: Bcd57: goto C1e39; D3d05: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto d7808; dd71e: $vhostTemplate->build(); goto Fc995; B4763: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto D8314; Fb43b: B970d: goto B4763; Ef9c8: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Eace7; e8424: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto bbde1; Ce01d: $phpSite = new PhpSite(); goto dd1b5; Cfadf: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto F4c06; C9aa5: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto f3af2; f3b85: d4bc3: goto ae064; Efdf0: $nodejsSite->setDomainName($domainName); goto a4801; Bf02e: $nodejsSiteCreator->createNginxVhost(); goto b0e64; Feec2: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto Efdf0; bd835: $nodejsSettingsEntity->setSite($siteEntity); goto E8843; e66b8: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto c57a1; F2b9f: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto D866d; c926e: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c7a62; f4de8: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Abdab; d75ec: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto dfce2; e9aa8: $subjectAlternativeNames[] = sprintf("\x77\x77\167\56\45\163", $domainName); goto f3b85; b3905: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E042c; E3a80: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto Bf02e; fb9e6: $nodejsSite->setUser($siteEntity->getUser()); goto Feec2; D907a: $rsaKeyGenerator = new RsaKeyGenerator(); goto e8350; e895d: $siteEntity->setCertificate($certificateEntity); goto Aa8c1; a4801: $nodejsSite->setRegistrableDomain($registrableDomain); goto b9d3e; B1935: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto b2ce8; b398f: $nodejsSiteCreator->createUser(); goto c8753; c7a62: $subdomain = false === empty($subdomain) ? $subdomain : null; goto c6816; f3af2: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a7725; E8843: $siteConstraints = $this->validator->validate($siteEntity); goto e0744; c6816: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto d5b7e; de811: Fe71c: goto ba2d9; a2093: $certificateEntity->setDefaultCertificate(true); goto Ba362; Ba362: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B5ff9; bbe12: goto C4056; goto c8743; bd9f2: $constraintViolationList = new ConstraintViolationList(); goto dbfac; d2f94: $siteEntity = $this->siteEntityManager->createEntity(); goto c83dc; B0c05: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto b3905; bd50a: $subjectAlternativeNames = []; goto d1c6c; c75ad: $nodejsSiteCreator->resetPermissions(); goto D8fad; B09f3: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto b398f; D9e15: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B1935; fceb8: C4056: goto d75ec; A6bb0: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto d3232; B5ff9: $certificateEntity->setCsr($csr); goto d4b7f; dfce2: if (!(false === empty($redirectionVhostTemplate))) { goto Fe71c; } goto D493c; ab523: $vhostTemplate->build(); goto B0c05; F81be: $constraintViolationList->addAll($nodejsSettingsConstraints); goto A2af8; ece97: $siteEntity->setVhostTemplate($vhostTemplate); goto D296e; A2af8: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto A6bb0; Ae923: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B09f3; d1c6c: if (!(true === is_null($subdomain))) { goto d4bc3; } goto e9aa8; Ba9ce: $siteEntity->setDomainName($domainName); goto Ec5c8; dbfac: $constraintViolationList->addAll($siteConstraints); goto F81be; D493c: $vhostTemplate = sprintf("\45\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto de811; bfaca: $certificateEntity->setCertificate($selfSignedCertificate); goto e895d; C142a: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\56\x2f\56\x2e\x2f\x72\x65\x73\157\x75\162\x63\x65\x73\57\x6e\147\x69\x6e\170\x2f\166\150\157\x73\164\x5f\x74\145\x6d\x70\x6c\x61\164\145\57\162\x65\x64\x69\162\x65\143\164\55\150\x74\x74\160\x33"); goto fceb8; F07cf: $nodejsSiteCreator->createNvmDirectory(); goto D6a02; d8080: $nodejsSite->setCertificate($certificateEntity); goto d1fd5; c65f9: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto d8080; e0744: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto F536e; A9296: $siteEntity->setUserPassword($siteUserPassword); goto ca954; ba2d9: ee2b8: goto ece97; c8743: A3cae: goto C142a; E042c: $this->siteEntityManager->updateEntity($siteEntity); goto C158c; D866d: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto eda4a; d1fd5: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto Ae923; C5c16: if (true === isset($_ENV["\x41\x50\x50\137\110\124\124\120\63"]) && "\x74\x72\165\145" === $_ENV["\101\120\120\x5f\110\124\124\x50\x33"]) { goto A3cae; } goto Cbe0f; Abdab: $certificateEntity->setSite($siteEntity); goto D907a; b9d3e: $nodejsSite->setSubdomain($subdomain); goto c65f9; eda4a: $nodejsSettingsEntity->setPort($port); goto bd835; ae064: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto e4c94; } goto b7ac6; a7725: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto c926e; Faaa9: $vhostTemplate->resetProcessors(); goto D9e15; d4b7f: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto bfaca; b0e64: $nodejsSiteCreator->reloadNginxService(); goto c75ad; c8753: $nodejsSiteCreator->createRootDirectory(); goto A5f42; b2ce8: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto ab523; c83dc: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto Ba9ce; ca954: $siteEntity->setRootDirectory($domainName); goto c1aaa; Ec5c8: $siteEntity->setUser($siteUser); goto A9296; e8350: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto bd50a; Aa8c1: $nodejsSite = new NodejsSite(); goto fb9e6; C158c: return $siteEntity; goto D1892; b7ac6: $subjectAlternativeNames[] = $registrableDomain; goto f6e92; D296e: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto F2b9f; d3232: Fbbee: goto f4de8; F536e: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Fbbee; } goto bd9f2; e8b56: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto e66b8; Cbe0f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\x2e\56\x2f\56\56\57\162\145\163\x6f\165\x72\x63\145\163\x2f\x6e\147\x69\156\x78\57\x76\150\157\163\164\137\x74\x65\x6d\160\x6c\x61\164\x65\57\162\145\x64\151\162\145\x63\x74"); goto bbe12; d5b7e: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto d2f94; f6e92: e4c94: goto e8b56; c57a1: $csr = $csrGenerator->generate(); goto D3251; D8fad: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto a7371; A5f42: $nodejsSiteCreator->createLogrotateFile(); goto F07cf; D6a02: $nodejsSiteCreator->installNodejs(); goto E3a80; a7371: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Faaa9; c1aaa: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto ee2b8; } goto C5c16; D3251: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto a2093; D1892: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Fb646; e755b: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto B5589; af131: C4d9b: goto Baa36; eb585: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto D5165; B5589: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto A6a49; a161c: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto cd3f6; d01f9: $pythonSiteCreator->createRootDirectory(); goto b51a4; E94a2: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto B49f0; Cf324: $pythonSite->setDomainName($domainName); goto aa60d; Fe5ef: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto d6e4b; de71c: dccb6: goto E94a2; C3c9e: $pythonSite->setPythonSettings($pythonSettingsEntity); goto Efb77; Aa71a: $pythonSite = new PythonSite(); goto f9c5e; A7c0b: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto E57a6; F8554: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto Fb512; cd3f6: $this->siteEntityManager->updateEntity($siteEntity); goto af63e; b51a4: $pythonSiteCreator->createLogrotateFile(); goto Aeb37; e5cb4: $subjectAlternativeNames[] = $registrableDomain; goto de71c; aa60d: $pythonSite->setRegistrableDomain($registrableDomain); goto b3b41; b74f5: $siteEntity->setPythonSettings($pythonSettingsEntity); goto F535e; D8735: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto C4d9b; } goto fb939; a5034: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto Cf324; d9e95: B7a81: goto af131; Fb646: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto f8eca; cc6d4: $siteEntity->setDomainName($domainName); goto A2159; e9afa: $siteEntity->setCertificate($certificateEntity); goto Aa71a; fb939: if (true === isset($_ENV["\101\120\120\137\x48\x54\124\120\x33"]) && "\x74\162\x75\x65" === $_ENV["\101\120\120\137\110\x54\x54\120\63"]) { goto C196b; } goto A9794; da30a: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Ed3e2; A2159: $siteEntity->setUser($siteUser); goto d3912; d6e4b: $siteEntity = $this->siteEntityManager->createEntity(); goto addb0; addb0: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto cc6d4; A15c2: $pythonSiteCreator->resetPermissions(); goto ca093; b4a1c: if (!(true === is_null($subdomain))) { goto Afed7; } goto e14dd; B4cc0: goto d01a8; goto D0a6a; A7422: $pythonSiteCreator->reloadNginxService(); goto A15c2; A6a49: $vhostTemplate->build(); goto a161c; b110d: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\x2e\x2f\x2e\x2e\x2f\x72\x65\163\157\x75\162\143\x65\x73\57\156\147\151\156\170\57\x76\150\x6f\x73\x74\137\x74\x65\x6d\160\x6c\x61\x74\x65\57\x72\x65\144\151\162\x65\x63\164\x2d\150\x74\164\x70\x33"); goto af470; D5165: $certificateEntity->setCertificate($selfSignedCertificate); goto e9afa; E4a35: $certificateEntity->setDefaultCertificate(true); goto a8a5e; c15a2: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto cceff; Ec3b8: ef086: goto d2a6b; a9903: $siteEntity->setRootDirectory($domainName); goto D8735; Fb512: $pythonSiteCreator->createUser(); goto d01f9; d1cc2: Afed7: goto A03a3; Aeb37: $pythonSiteCreator->writePythonVersionFile(); goto Bf3c0; b4507: $pythonSettingsEntity->setPort($port); goto eff5a; af63e: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto b4180; b4180: return $siteEntity; goto B75d9; d3912: $siteEntity->setUserPassword($siteUserPassword); goto a9903; D64de: $constraintViolationList->addAll($siteConstraints); goto c832d; af470: d01a8: goto A7c0b; e14dd: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\56\45\x73", $domainName); goto d1cc2; Ed3e2: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto Fe5ef; Fbefd: $subjectAlternativeNames = []; goto b4a1c; E57a6: if (!(false === empty($redirectionVhostTemplate))) { goto B7a81; } goto cbe4f; B9f92: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Fbefd; c832d: $constraintViolationList->addAll($pythonSettingsConstraints); goto ea4d3; ead95: $csr = $csrGenerator->generate(); goto Ee29b; cceff: $vhostTemplate->resetProcessors(); goto Ea711; A03a3: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto dccb6; } goto e5cb4; C6033: $pythonSettingsEntity = new PythonSettingsEntity(); goto b74f5; Ee29b: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto E4a35; aed45: $pythonSiteCreator->createNginxVhost(); goto A7422; A9794: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\57\56\56\57\162\x65\163\157\165\162\x63\145\x73\57\x6e\x67\x69\156\170\57\x76\150\x6f\x73\x74\x5f\x74\x65\x6d\x70\x6c\x61\x74\x65\57\162\x65\144\151\162\145\x63\x74"); goto B4cc0; Abc84: $siteConstraints = $this->validator->validate($siteEntity); goto Ded67; f9c5e: $pythonSite->setUser($siteEntity->getUser()); goto a5034; ca093: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto c15a2; Efb77: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto F8554; Ded67: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto bbfb1; cbe4f: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto d9e95; Bf3c0: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto aed45; e4171: $certificateEntity->setCsr($csr); goto eb585; B49f0: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto ead95; D0a6a: C196b: goto b110d; eff5a: $pythonSettingsEntity->setSite($siteEntity); goto Abc84; C513d: $rsaKeyGenerator = new RsaKeyGenerator(); goto B9f92; F535e: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto b4507; Ebc4b: throw new \Exception(implode("\73\40", $errorMessages)); goto Ec3b8; Cfffe: $pythonSite->setCertificate($certificateEntity); goto C3c9e; d2a6b: $certificateEntity = $this->certificateEntityManager->createEntity(); goto a7d0e; ea4d3: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Ebc4b; dd18f: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto Cfffe; a7d0e: $certificateEntity->setSite($siteEntity); goto C513d; Ea711: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto e755b; bbfb1: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto ef086; } goto C9c2b; a8a5e: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto e4171; b3b41: $pythonSite->setSubdomain($subdomain); goto dd18f; f8eca: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto dfc26; dfc26: $subdomain = $resolvedDomainName->subDomain()->toString(); goto da30a; C9c2b: $constraintViolationList = new ConstraintViolationList(); goto D64de; Baa36: $siteEntity->setVhostTemplate($vhostTemplate); goto C6033; B75d9: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto C304f; d03ee: $siteEntity->setDomainName($domainName); goto A9b0a; f4996: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\56\x2e\x2f\x2e\56\57\x72\145\x73\x6f\x75\x72\143\145\x73\x2f\156\x67\151\x6e\170\x2f\x76\150\x6f\163\164\x5f\x74\145\155\x70\154\x61\164\145\x2f\162\145\x64\151\162\145\x63\164"); goto dd703; F252b: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto Ab6c3; D45da: $constraintViolationList->addAll($siteConstraints); goto A7fca; f3ad7: $staticSite->setRegistrableDomain($registrableDomain); goto Ed1ef; E6104: $siteEntity->setCertificate($certificateEntity); goto Fdadf; F1895: $staticSiteCreator->resetPermissions(); goto ca9a3; B4773: $siteEntity->setVhostTemplate($vhostTemplate); goto afd11; Fdd1a: if (true === isset($_ENV["\101\120\120\x5f\110\124\124\120\x33"]) && "\x74\x72\x75\145" === $_ENV["\x41\x50\120\x5f\x48\x54\x54\120\x33"]) { goto C23a7; } goto f4996; Df854: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Bec08; F97d1: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e72e8; B1529: $subjectAlternativeNames[] = sprintf("\167\x77\167\56\45\x73", $domainName); goto C7159; B7818: $constraintViolationList = new ConstraintViolationList(); goto D45da; Bace6: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ed827; A9c9e: $certificateEntity->setCsr($csr); goto Df854; Ebae8: $vhostTemplate->build(); goto b74b0; F0465: $certificateEntity = $this->certificateEntityManager->createEntity(); goto cbd77; f385e: fa0df: goto B4773; f01ed: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B5199; cbe83: $staticSiteCreator->createIndexHtml(); goto Cf2f1; D20ff: $this->siteEntityManager->updateEntity($siteEntity); goto d3901; B5169: $siteEntity->setRootDirectory($domainName); goto be9a2; ca9a3: $vhostTemplate = new StaticVhostTemplate($staticSite); goto a6a41; Ae7d4: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto A9c9e; c338e: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto d03ee; b74b0: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto e1751; f60a7: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F97d1; eba29: $staticSite->setUser($siteEntity->getUser()); goto ba96c; Ed1ef: $staticSite->setSubdomain($subdomain); goto F252b; C304f: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto C6786; ba96c: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto A9471; F7270: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\x2e\56\x2f\56\56\x2f\x72\x65\x73\157\165\x72\143\145\x73\x2f\156\147\x69\x6e\x78\x2f\166\x68\157\x73\164\137\x74\x65\155\x70\154\x61\x74\145\57\x72\x65\x64\x69\162\145\x63\x74\x2d\x68\164\x74\160\63"); goto Fbabc; e1751: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto D20ff; ece10: $rsaKeyGenerator = new RsaKeyGenerator(); goto Fb1c2; dd7f2: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Af051; Cb8f5: $staticSiteCreator->createUser(); goto cfab9; d6b61: $staticSiteCreator->createNginxVhost(); goto Ee4c7; Eb9d2: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f042e; e72e8: $csr = $csrGenerator->generate(); goto abd26; dd703: goto Fdd58; goto cf0cb; a6a41: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Dcb47; d3901: return $siteEntity; goto d172e; C7159: E9667: goto f3fdc; Fb1c2: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto edc3a; Ceeca: b1d16: goto F0465; db339: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto c86a0; C7215: fd81d: goto f385e; f3fdc: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto fa3cf; } goto c97fa; afd11: $siteConstraints = $this->validator->validate($siteEntity); goto eec18; Ab6c3: $staticSite->setCertificate($certificateEntity); goto f01ed; c86a0: $siteEntity = $this->siteEntityManager->createEntity(); goto c338e; cf0cb: C23a7: goto F7270; A9471: $staticSite->setDomainName($domainName); goto f3ad7; be9a2: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto fa0df; } goto Fdd1a; Ee4c7: $staticSiteCreator->reloadNginxService(); goto F1895; Cf2f1: $staticSiteCreator->createPrivateKeyAndCertificate(); goto d6b61; Ef35e: $certificateEntity->setDefaultCertificate(true); goto Ae7d4; cfab9: $staticSiteCreator->createRootDirectory(); goto Dc2a7; Fbabc: Fdd58: goto dd7f2; c278c: if (!(true === is_null($subdomain))) { goto E9667; } goto B1529; abd26: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Ef35e; Dc2a7: $staticSiteCreator->createLogrotateFile(); goto cbe83; B5199: $staticSiteCreator = new StaticSiteCreator($staticSite); goto Cb8f5; Bec08: $certificateEntity->setCertificate($selfSignedCertificate); goto E6104; c97fa: $subjectAlternativeNames[] = $registrableDomain; goto a5c43; Af051: if (!(false === empty($redirectionVhostTemplate))) { goto fd81d; } goto cf233; C6786: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Eb9d2; edc3a: $subjectAlternativeNames = []; goto c278c; A7fca: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Cd010; F8d75: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto db339; Cd010: throw new \Exception(implode("\73\x20", $errorMessages)); goto Ceeca; Dcb47: $vhostTemplate->resetProcessors(); goto F5765; eec18: if (!count($siteConstraints)) { goto b1d16; } goto B7818; B3c22: $siteEntity->setUserPassword($siteUserPassword); goto B5169; ed827: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Ebae8; f042e: $subdomain = false === empty($subdomain) ? $subdomain : null; goto F8d75; F5765: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Bace6; cbd77: $certificateEntity->setSite($siteEntity); goto ece10; A9b0a: $siteEntity->setUser($siteUser); goto B3c22; Fdadf: $staticSite = new StaticSite(); goto eba29; cf233: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto C7215; a5c43: fa3cf: goto f60a7; d172e: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto a2fc7; D6b33: $reversProxySiteCreator->reloadNginxService(); goto da160; Bf883: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto e5a81; F5461: $certificateEntity->setSite($siteEntity); goto C1039; Aad3c: $reverseProxySite->setUser($siteEntity->getUser()); goto D1cf5; Cba13: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto A179a; d032f: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto C50ae; dd36a: $csr = $csrGenerator->generate(); goto Cba13; Ab0bd: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Fa105; A95e9: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ef987; E1edd: if (!(true === is_null($subdomain))) { goto E1cfc; } goto B7750; Bd97e: if (!count($siteConstraints)) { goto df970; } goto Adcd2; affe2: A8fde: goto C0845; aea56: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto C8ad4; C56d9: $reverseProxySite->setRegistrableDomain($registrableDomain); goto Ec04a; Bbf1f: throw new \Exception(implode("\73\x20", $errorMessages)); goto A72f4; da0d3: $certificateEntity->setCertificate($selfSignedCertificate); goto df1b7; Adcd2: $constraintViolationList = new ConstraintViolationList(); goto C39bd; Eb0c6: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto faae3; b9424: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Dd118; fa9ce: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto da0d3; A6f0a: $siteConstraints = $this->validator->validate($siteEntity); goto Bd97e; E9b99: $siteEntity->setRootDirectory($domainName); goto aea56; C0845: b3d68: goto Dfba2; e5a81: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto F8973; C1039: $rsaKeyGenerator = new RsaKeyGenerator(); goto C2ffa; ef987: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto Eb0c6; d5565: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Bf883; Fa1d9: $this->siteEntityManager->updateEntity($siteEntity); goto A12d0; fdcf9: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Aa04d; f9010: $reversProxySiteCreator->createLogrotateFile(); goto A77f5; f1c66: E1cfc: goto C9a2d; D7d5e: $siteEntity->setUserPassword($siteUserPassword); goto E9b99; ef07e: C7640: goto fdcf9; Aa04d: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto dd36a; Ef99b: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto d032f; C2ffa: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c280f; F8973: $vhostTemplate->build(); goto b9424; D7188: $reverseProxySite->setDomainName($domainName); goto C56d9; A179a: $certificateEntity->setDefaultCertificate(true); goto Ab0bd; Fa105: $certificateEntity->setCsr($csr); goto fa9ce; C39bd: $constraintViolationList->addAll($siteConstraints); goto D506b; A72f4: df970: goto a3694; faae3: $siteEntity = $this->siteEntityManager->createEntity(); goto F8400; Dd118: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Fa1d9; c4138: C8067: goto e1328; Cc87c: $reversProxySiteCreator->createNginxVhost(); goto D6b33; c280f: $subjectAlternativeNames = []; goto E1edd; A12d0: return $siteEntity; goto Ad061; Dfba2: $siteEntity->setVhostTemplate($vhostTemplate); goto A6f0a; D506b: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Bbf1f; Ec04a: $reverseProxySite->setSubdomain($subdomain); goto d07e8; beb14: if (!(false === empty($redirectionVhostTemplate))) { goto A8fde; } goto F937f; e4745: $siteEntity->setDomainName($domainName); goto B7a0c; E6cb9: if (true === isset($_ENV["\x41\120\x50\x5f\x48\x54\x54\120\63"]) && "\x74\x72\x75\145" === $_ENV["\x41\x50\120\x5f\x48\124\x54\120\x33"]) { goto C8067; } goto ba211; Be068: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto De41f; a2fc7: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto f17ec; F8400: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto e4745; ad21c: A0183: goto Ee79f; F09ba: $subdomain = $resolvedDomainName->subDomain()->toString(); goto A95e9; C8ad4: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto b3d68; } goto E6cb9; B7750: $subjectAlternativeNames[] = sprintf("\x77\x77\167\56\x25\x73", $domainName); goto f1c66; a3694: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F5461; da160: $reversProxySiteCreator->resetPermissions(); goto Ef99b; D1cf5: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto D7188; a3371: $reverseProxySite->setCertificate($certificateEntity); goto c7173; c7173: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto Be068; B7a0c: $siteEntity->setUser($siteUser); goto D7d5e; f7c24: $subjectAlternativeNames[] = $registrableDomain; goto ef07e; e1328: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\56\56\57\56\56\57\x72\145\163\x6f\165\162\x63\x65\x73\x2f\156\x67\x69\x6e\x78\57\x76\150\157\x73\x74\x5f\164\x65\x6d\160\x6c\x61\164\x65\57\x72\x65\x64\151\x72\x65\x63\164\55\150\x74\164\x70\63"); goto ad21c; C50ae: $vhostTemplate->resetProcessors(); goto d5565; F937f: $vhostTemplate = sprintf("\45\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto affe2; C9a2d: if (!(false === is_null($subdomain) && "\167\x77\x77" == $subdomain)) { goto C7640; } goto f7c24; De41f: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto Ae43e; ba211: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\56\x2e\x2f\56\x2e\57\x72\x65\x73\157\165\162\x63\145\x73\57\x6e\x67\151\156\x78\57\166\x68\157\163\164\137\164\145\x6d\160\x6c\x61\x74\x65\x2f\162\x65\144\x69\162\x65\143\164"); goto a2dc3; Dfe2f: $reverseProxySite = new ReverseProxySite(); goto Aad3c; E39e5: $reversProxySiteCreator->createRootDirectory(); goto f9010; a2dc3: goto A0183; goto c4138; d07e8: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto a3371; Ae43e: $reversProxySiteCreator->createUser(); goto E39e5; df1b7: $siteEntity->setCertificate($certificateEntity); goto Dfe2f; Ee79f: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto beb14; f17ec: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto F09ba; A77f5: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Cc87c; Ad061: } public function installedWordPressSite(Request $request) : Response { goto A3f16; c8c3d: return $response; goto a9558; aa6fd: if (false === empty($siteCredentials)) { goto c72c7; } goto bdcd5; b9ed0: $response = $this->render("\x46\162\x6f\156\164\x65\156\x64\x2f\123\x69\x74\x65\57\116\x65\167\57\167\x6f\x72\144\160\x72\145\x73\163\55\151\156\x73\x74\141\x6c\x6c\145\x64\56\150\164\155\154\56\164\x77\151\x67", ["\163\151\x74\145\x43\162\145\144\145\x6e\x74\151\141\154\163" => $siteCredentials]); goto f69b7; Be50e: $siteCredentials = $session->get("\x73\x69\x74\x65\x43\x72\x65\144\145\156\164\151\x61\154\x73"); goto aa6fd; C71e5: goto fef68; goto cf197; f0b15: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto b9ed0; f69b7: return $response; goto a865d; cf197: c72c7: goto f0b15; A3f16: $session = $request->getSession(); goto Be50e; a865d: fef68: goto c8c3d; bdcd5: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\151\x74\145\x73")); goto C71e5; a9558: } private function renderSiteCredentials(array $siteCredentials) : string { goto E1807; C8fde: return $renderedCredentials; goto Ae5e7; E1807: $renderedCredentials = ''; goto fe51a; F5c5f: Df0c8: goto C8fde; fe51a: foreach ($siteCredentials as $section => $sectionData) { goto F8316; f8569: Ba798: goto b7beb; b46e7: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\163\x3a\x20\x25\163", $key, $value) . PHP_EOL; a4766: } goto e59af; e59af: B9b2f: goto ad847; ad847: $renderedCredentials .= PHP_EOL; goto f8569; F8316: $renderedCredentials .= $section . PHP_EOL; goto A2386; A2386: $renderedCredentials .= "\x2d\55\x2d\55\x2d\x2d\55\x2d\55\x2d\x2d\x2d\x2d\x2d\55\55\x2d\55\55\x2d\55\x2d\55\x2d\x2d\x2d\55\x2d\55\55\x2d\x2d\x2d\x2d\x2d\x2d\55\x2d\55\55\55\55\55\x2d\x2d\x2d\x2d\x2d\x2d\55\55\55\55\55" . PHP_EOL; goto b46e7; b7beb: } goto F5c5f; Ae5e7: } private function getVhostTemplateEntity(string $name) : mixed { goto E3f1f; ff9d2: return $vhostTemplateEntity; goto D1a32; e85d4: A59ad: goto ff9d2; e1503: if (!(true === is_null($vhostTemplateEntity))) { goto A59ad; } goto ff1ab; ff1ab: throw new \Exception($this->translator->trans("\x56\150\157\x73\164\40\x54\x65\155\160\x6c\141\164\145\40\x25\x76\x68\157\163\x74\124\145\x6d\160\x6c\x61\x74\x65\x25\40\144\157\145\163\40\x6e\x6f\164\40\145\170\x69\x73\164\56", ["\x25\166\150\x6f\x73\x74\124\x65\155\160\x6c\141\164\x65\x25" => $name])); goto e85d4; E3f1f: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto e1503; D1a32: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto e3b29; e3b29: $errorMessages = []; goto cb808; cb808: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\45\163\72\x20\x25\x73", $constraint->getPropertyPath(), $constraint->getMessage()); e9826: } goto D1c80; E334a: return $errorMessages; goto D6fc3; D1c80: Da016: goto E334a; D6fc3: } private function generateNameFromDomainName(string $domainName) : string { goto d7582; D9ba4: Dbf9a: goto dce36; d7443: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto A5f0f; Fcd43: if (!(false === empty($subdomain))) { goto b82b6; } goto d1e2d; d7582: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto d7443; e361b: $name = $explodedRegistrableDomain[0] ?? ''; goto D9ba4; A2e34: b82b6: goto A0c9e; cc479: D0f09: goto e361b; D0229: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto Af01d; A5f0f: $subdomain = $resolvedDomainName->subDomain()->toString(); goto D0229; b6fa6: $name = $explodedRegistrableDomain[0] ?? ''; goto Fcd43; A0c9e: goto Dbf9a; goto cc479; cb4ce: $name = sprintf("\45\x73\55\45\163", $explodedRegistrableDomain[0] ?? '', implode("\55", $explodedSubdomain)); goto A2e34; dce36: return $name; goto b68c2; d1e2d: $explodedSubdomain = explode("\x2e", $subdomain); goto cb4ce; Af01d: if ("\x77\x77\x77" == $subdomain) { goto D0f09; } goto b6fa6; b68c2: } private function getUniqueDatabaseName(string $databaseName) : string { goto B0bbe; B0bbe: $uniqueDatabaseName = $databaseName; goto C9856; b0be1: c4277: goto C19eb; b4567: e90a7: goto D8a7d; Fe7b0: $databases = $databaseConnection->getDatabases(); goto b4567; f21a4: $i++; goto D9a03; c091d: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto A833b; cf252: Ba938: goto Ca716; D8a7d: if (!(0 < $i)) { goto c24fd; } goto D4776; ced62: $databaseExists = in_array($uniqueDatabaseName, $databases); goto f21a4; D9a03: if (true === $databaseExists) { goto e90a7; } goto b0be1; b196c: c24fd: goto ced62; Adc82: $uniqueDatabaseName = sprintf("\x25\163\55\x64\x62", $uniqueDatabaseName); goto cf252; C19eb: return $uniqueDatabaseName; goto E5e2e; Ca716: $i = 0; goto c091d; A833b: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto Fe7b0; D4776: $uniqueDatabaseName = sprintf("\45\x73\x2d\45\x73", $databaseName, $i); goto b196c; C9856: if (!(strlen($uniqueDatabaseName) <= 3)) { goto Ba938; } goto Adc82; E5e2e: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto d6781; A6131: return $uniqueDatabaseUserName; goto c837c; F4acb: $i = 0; goto Bad03; E87ec: ac527: goto F4acb; bb343: $i++; goto b316d; Bad03: d3528: goto D3625; b316d: if (false === is_null($databaseUserEntity)) { goto d3528; } goto C5935; d8c93: B953c: goto Af1fe; A1671: $uniqueDatabaseUserName = sprintf("\x25\x73\x2d\x25\x73", $databaseUserName, $i); goto d8c93; d6781: $uniqueDatabaseUserName = $databaseUserName; goto E48d9; E48d9: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto ac527; } goto Cebf9; Cebf9: $uniqueDatabaseUserName = sprintf("\45\x73\x2d\144\142", $uniqueDatabaseUserName); goto E87ec; C5935: f9832: goto F43f4; F43f4: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto A6131; D3625: if (!(0 < $i)) { goto B953c; } goto A1671; Af1fe: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto bb343; c837c: } private function hasPermissions() : bool { goto C3289; fa630: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto c1363; } goto db530; b1a97: c1363: goto f0ab8; f0ab8: return false; goto A1019; db530: return true; goto b1a97; C3289: $user = $this->getUser(); goto fa630; A1019: } }
